#########################################
Welcome to the Django hvad documentation!
#########################################

******************
About this project
******************

django-hvad provides a high level API to maintain multilingual content in your
database using the Django ORM.

*************************
Before you dive into this
*************************

Please note that this documentation assumes that you are very familiar with 
Django and Python, if you are not, please familiarize yourself with those first.

While django-hvad tries to be as simple to use as possible, it's still
recommended that you only use it if you consider yourself to be very strong in
Python and Django.

************************
Notes on Django versions
************************

django-hvad is tested on the following configurations:

- Django 1.3.7, running Python 2.6 or 2.7.
- Django 1.4.15, running Python 2.6 or 2.7.
- Django 1.5.10, running Python 2.6, 2.7 or 3.3.
- Django 1.6.7, running Python 2.7 or 3.3.
- Django 1.7.0, running Python 2.7, 3.3 or 3.4.


***************
Contents
***************

.. toctree::
    :maxdepth: 3
    :titlesonly:
    :numbered: 2

    public/installation
    public/quickstart
    public/models
    public/queryset
    public/forms
    public/admin
    public/faq
    public/release_notes
    public/contact
    public/contributing
    internal/index

    glossary
    

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`
